#statistics

**Principal Component Analysis** is a statistical technique used to reduce the dimensionality of data while retaining the maximum possible covariance.

Correlation between components indicates that those components are not orthogonal. By re-projecting data onto a lower number of orthogonal axes (therefore with no correlation), PCA allows to use the minimum possible amount of axes to explain the data, with the catch that those new axes will often not bear any resemblance to the original axes.